@@ -8,6 +8,7 @@ from django.conf import settings
 from django.db import transaction
 from django.http import HttpResponseBadRequest
 from django.http import HttpResponseRedirect
+from django.shortcuts import render
 from django.urls import reverse
 
 import core.models as models
@@ -26,7 +27,6 @@ class Base(Stateful):
     """This class contains methods that are needed by all pages."""
 
     def __init__(self) -> None:
-        self.logger = logging.getLogger("raveberry")
         self.settings = Settings(self)
         self.user_manager = UserManager(self)
         self.lights = Lights(self)
@@ -88,6 +88,11 @@ class Base(Stateful):
             else "youtube",
         }
 
+    def no_stream(self, request: WSGIRequest) -> HttpResponse:
+        """Renders the /stream page. If this is reached, there is no stream active."""
+        context = self.context(request)
+        return render(request, "no_stream.html", context)
+
     @classmethod
     def submit_hashtag(cls, request: WSGIRequest) -> HttpResponse:
         """Add the given hashtag to the database."""
