@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+import logging
 import os
 import random
 import re
@@ -13,8 +14,6 @@ from threading import Event
 from threading import Lock
 from threading import Semaphore
 
-import mopidy.backend
-import mopidy.core
 from django.conf import settings
 from django.db import transaction
 from django.db.models import F
@@ -158,10 +157,7 @@ class Player:
         paused = False
         with self.mopidy_command() as allowed:
             if allowed:
-                paused = (
-                    self.player.playback.get_state()
-                    != mopidy.core.PlaybackState.PLAYING
-                )
+                paused = self.player.playback.get_state() != "playing"
         return paused
 
     @background_thread
@@ -208,7 +204,7 @@ class Player:
                 if song is None:
                     # either the semaphore didn't match up with the actual count
                     # of songs in the queue or a race condition occured
-                    self.musiq.base.logger.info("dequeued on empty list")
+                    logging.warning("dequeued on empty list")
                     continue
 
                 current_song = models.CurrentSong.objects.create(
@@ -322,10 +318,7 @@ class Player:
             with self.mopidy_command() as allowed:
                 if allowed:
                     try:
-                        if (
-                            self.player.playback.get_state()
-                            == mopidy.core.PlaybackState.STOPPED
-                        ):
+                        if self.player.playback.get_state() == "stopped":
                             break
                     except (requests.exceptions.ConnectionError, MopidyError):
                         # error during state get, skip until reconnected
@@ -353,8 +346,7 @@ class Player:
                 # As this function can raise several exceptions (it might do networking)
                 # we catch every exception to make sure the loop keeps running
             except Exception as e:  # pylint: disable=broad-except
-                self.musiq.base.logger.error("error during suggestions for " + url)
-                self.musiq.base.logger.error(e)
+                logging.exception("error during suggestions for " + url)
             else:
                 self.musiq.do_request_music(
                     "",
@@ -383,7 +375,7 @@ class Player:
             yield True
             self.player_lock.release()
         else:
-            print("mopidy command could not be executed")
+            logging.warning("mopidy command could not be executed")
             yield False
 
     @disabled_when_voting
