@@ -4,6 +4,7 @@
 from __future__ import annotations
 
 import configparser
+import logging
 import math
 import os
 import re
@@ -87,6 +88,7 @@ class Settings(Stateful):
         self.downvotes_to_kick = int(self.get_setting("downvotes_to_kick", "3"))
         self.max_download_size = int(self.get_setting("max_download_size", "10"))
         self.max_playlist_items = int(self.get_setting("max_playlist_items", "10"))
+        self.youtube_enabled = self.get_setting("youtube_enabled", "True") == "True"
         self.spotify_username = self.get_setting("spotify_username", "")
         self.spotify_password = self.get_setting("spotify_password", "")
         self.spotify_client_id = self.get_setting("spotify_client_id", "")
@@ -111,6 +113,8 @@ class Settings(Stateful):
         state_dict["max_playlist_items"] = self.max_playlist_items
         state_dict["has_internet"] = self.has_internet
 
+        state_dict["youtube_enabled"] = self.youtube_enabled
+
         state_dict["spotify_credentials_valid"] = self.spotify_enabled
 
         state_dict["bluetooth_scanning"] = self.bluetoothctl is not None
@@ -124,10 +128,14 @@ class Settings(Stateful):
 
         state_dict["scan_progress"] = self.scan_progress
 
-        # icecast reports as active even if it is internally disabled.
-        # check if its port is used to determine if it's running
-        with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
-            streaming_enabled = s.connect_ex(("localhost", 8000)) == 0
+        if settings.DOCKER and not settings.DOCKER_ICECAST:
+            # icecast is definitely disabled
+            streaming_enabled = False
+        else:
+            # the icecast service reports as active even if it is internally disabled.
+            # check if its port is used to determine if it's running
+            with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
+                streaming_enabled = s.connect_ex((settings.ICECAST_HOST, 8000)) == 0
         state_dict["streaming_enabled"] = streaming_enabled
 
         try:
@@ -151,7 +159,7 @@ class Settings(Stateful):
                 subprocess.call(["/usr/local/sbin/raveberry/remote_enabled"]) != 0
             )
         except FileNotFoundError:
-            self.base.logger.error("scripts not installed")
+            logging.info("scripts not installed")
 
         return state_dict
 
@@ -331,6 +339,13 @@ class Settings(Stateful):
         """Check whether the provided credentials are valid."""
         return self._check_spotify()
 
+    @option
+    def set_youtube_enabled(self, request: WSGIRequest):
+        """Enables or disables youtube to be used as a song provider."""
+        enabled = request.POST.get("value") == "true"
+        Setting.objects.filter(key="youtube_enabled").update(value=enabled)
+        self.youtube_enabled = enabled
+
     @option
     def set_spotify_credentials(self, request: WSGIRequest) -> HttpResponse:
         """Update spotify credentials."""
@@ -489,31 +504,70 @@ class Settings(Stateful):
         if error:
             return HttpResponseBadRequest(error)
 
-        # parse the sink number of the bluetooth device from pactl
-        sinks = subprocess.check_output(
-            "pactl list short sinks".split(), universal_newlines=True
-        )
-        bluetooth_sink = "2"
-        for sink in sinks.split("\n"):
-            if "bluez" in sink:
-                bluetooth_sink = sink[0]
-                break
-        subprocess.call(
-            f"pactl set-default-sink {bluetooth_sink}".split(),
-            stdout=subprocess.DEVNULL,
-        )
-        # restart mopidy to apply audio device change
-        subprocess.call(["sudo", "/usr/local/sbin/raveberry/restart_mopidy"])
-
-        return HttpResponse("Connected")
+        return HttpResponse("Connected. Set output device to activate.")
 
     @option
-    def disconnect_bluetooth(self, _request: WSGIRequest) -> HttpResponse:
-        """Disconnect from the current bluetooth device."""
-        subprocess.call("pactl set-default-sink 0".split(), stdout=subprocess.DEVNULL)
+    def disconnect_bluetooth(self, request: WSGIRequest) -> HttpResponse:
+        """Untrusts a given bluetooth device to prevent automatic reconnects.
+        Does not unpair or remove the device."""
+        address = request.POST.get("address")
+        if self.bluetoothctl is not None:
+            return HttpResponseBadRequest("Stop scanning before disconnecting")
+        if address is None or address == "":
+            return HttpResponseBadRequest("No device selected")
+
+        self.bluetoothctl = subprocess.Popen(
+            ["bluetoothctl"], stdin=subprocess.PIPE, stdout=subprocess.PIPE
+        )
+        assert self.bluetoothctl.stdin
+        error = ""
+
+        self.bluetoothctl.stdin.write(b"untrust " + address.encode() + b"\n")
+        self.bluetoothctl.stdin.flush()
+        while True:
+            line = self._get_bluetoothctl_line()
+            if not line:
+                break
+            if re.match(".*Device " + address + " not available", line):
+                error = "Device unavailable"
+                break
+            if re.match(".*untrust succeeded", line):
+                break
+
+        self._stop_bluetoothctl()
+        if error:
+            return HttpResponseBadRequest(error)
+        return HttpResponse("Disconnected")
+
+    @option
+    def output_devices(self, _request: WSGIRequest) -> JsonResponse:
+        """Returns a list of all sound output devices currently available."""
+        sinks = subprocess.check_output(
+            "pactl list short sinks".split(),
+            env={"PULSE_SERVER": "127.0.0.1"},
+            universal_newlines=True,
+        )
+        sinks = [sink.split() for sink in sinks.splitlines()]
+        sinks = [sink[1] for sink in sinks if len(sink) >= 2]
+        return JsonResponse(sinks, safe=False)
+
+    @option
+    def set_output_device(self, request: WSGIRequest) -> HttpResponse:
+        """Sets the given device as default output device."""
+        device = request.POST.get("device")
+        if not device:
+            return HttpResponseBadRequest("No device selected")
+
+        subprocess.call(
+            f"pactl set-default-sink {device}".split(),
+            stdout=subprocess.DEVNULL,
+            env={"PULSE_SERVER": "127.0.0.1"},
+        )
         # restart mopidy to apply audio device change
         subprocess.call(["sudo", "/usr/local/sbin/raveberry/restart_mopidy"])
-        return HttpResponse("Disconnected")
+        return HttpResponse(
+            f"Set default output. Restarting the current song might be necessary."
+        )
 
     @option
     def available_ssids(self, _request: WSGIRequest) -> JsonResponse:
@@ -636,7 +690,7 @@ class Settings(Stateful):
             pass
         os.symlink(library_path, library_link)
 
-        self.base.logger.info(f"started scanning in {library_path}")
+        logging.info(f"started scanning in {library_path}")
 
         self.scan_progress = f"{filecount} / 0 / 0"
         self.update_state()
@@ -676,7 +730,7 @@ class Settings(Stateful):
         self.scan_progress = f"{filecount} / {files_scanned} / {files_added}"
         self.update_state()
 
-        self.base.logger.info(f"done scanning in {library_path}")
+        logging.info(f"done scanning in {library_path}")
 
     @option
     def create_playlists(self, _request: WSGIRequest) -> HttpResponse:
@@ -701,7 +755,7 @@ class Settings(Stateful):
         library_link = os.path.join(settings.SONGS_CACHE_DIR, "local_library")
         library_path = os.path.abspath(library_link)
 
-        self.base.logger.info(f"started creating playlists in {library_path}")
+        logging.info(f"started creating playlists in {library_path}")
 
         self.scan_progress = f"{local_files} / 0 / 0"
         self.update_state()
@@ -756,7 +810,7 @@ class Settings(Stateful):
         self.scan_progress = f"{local_files} / {files_processed} / {files_added}"
         self.update_state()
 
-        self.base.logger.info(f"finished creating playlists in {library_path}")
+        logging.info(f"finished creating playlists in {library_path}")
 
     @option
     def analyse(self, request: WSGIRequest) -> HttpResponse:
@@ -861,6 +915,11 @@ class Settings(Stateful):
     @option
     def enable_streaming(self, _request: WSGIRequest) -> HttpResponse:
         """Enable icecast streaming."""
+        if settings.DOCKER:
+            return HttpResponseBadRequest(
+                "Choose the correct docker-compose file to control streaming"
+            )
+
         icecast_exists = False
         for line in subprocess.check_output(
             "systemctl list-unit-files --full --all".split(), universal_newlines=True
@@ -878,11 +937,16 @@ class Settings(Stateful):
         return HttpResponse()
 
     @option
-    def disable_streaming(self, _request: WSGIRequest) -> None:
+    def disable_streaming(self, _request: WSGIRequest) -> HttpResponse:
         """Disable icecast streaming."""
+        if settings.DOCKER:
+            return HttpResponseBadRequest(
+                "Choose the correct docker-compose file to control streaming"
+            )
         subprocess.call(["sudo", "/usr/local/sbin/raveberry/disable_streaming"])
         config_file = self._get_mopidy_config()
         self._update_mopidy_config(config_file)
+        return HttpResponse()
 
     @option
     def disable_events(self, _request: WSGIRequest) -> None:
