@@ -141,6 +141,11 @@ else:
             BASE.settings.update_user_count,
             name="update_user_count",
         ),
+        path(
+            "set_youtube_enabled/",
+            BASE.settings.set_youtube_enabled,
+            name="set_youtube_enabled",
+        ),
         path(
             "check_spotify_credentials/",
             BASE.settings.check_spotify_credentials,
@@ -166,6 +171,12 @@ else:
             BASE.settings.disconnect_bluetooth,
             name="disconnect_bluetooth",
         ),
+        path("output_devices/", BASE.settings.output_devices, name="output_devices",),
+        path(
+            "set_output_device/",
+            BASE.settings.set_output_device,
+            name="set_output_device",
+        ),
         path("available_ssids/", BASE.settings.available_ssids, name="available_ssids"),
         path("connect_to_wifi/", BASE.settings.connect_to_wifi, name="connect_to_wifi"),
         path("enable_homewifi/", BASE.settings.enable_homewifi, name="enable_homewifi"),
@@ -223,6 +234,7 @@ else:
         path("musiq/", BASE.musiq.index, name="musiq"),
         path("lights/", BASE.lights.index, name="lights"),
         path("pad/", BASE.pad.index, name="pad"),
+        path("stream/", BASE.no_stream, name="no_stream"),
         path("settings/", BASE.settings.index, name="settings"),
         path("accounts/", include("django.contrib.auth.urls")),
         path("login/", RedirectView.as_view(pattern_name="login", permanent=False)),
