@@ -1,10 +1,11 @@
 #!/bin/bash
+ADMIN_PASSWORD="${ADMIN_PASSWORD:-admin}"
 echo "Performing Migrations"
 DJANGO_DEBUG=1 DJANGO_MOCK=1 python3 manage.py migrate
 echo "Creating Users"
 DJANGO_DEBUG=1 DJANGO_MOCK=1 python3 manage.py shell <<-EOF
 	from django.contrib.auth.models import User
-	User.objects.create_superuser('admin', email='', password='admin')
+	User.objects.create_superuser('admin', email='', password='$ADMIN_PASSWORD')
 	User.objects.create_user('mod', password='mod')
 	User.objects.create_user('pad', password='pad')
 EOF
@@ -14,3 +15,11 @@ if [[ ! -d static/libs ]]; then
 fi
 echo "Compiling SCSS Files"
 DJANGO_MOCK=1 DJANGO_DEBUG=1 python3 manage.py compilescss
+
+if [ "$ADMIN_PASSWORD" == "admin" ]; then
+  echo 1>&2
+  echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!" 1>&2
+  echo "! Warning! Default admin password used, please consider changing it! !" 1>&2
+  echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!" 1>&2
+  echo 1>&2
+fi
