@@ -14,6 +14,8 @@ specificState = function (newState) {
 	$('#max_playlist_items').val(newState.max_playlist_items);
 	$('#has_internet').prop("checked", newState.has_internet);
 
+	$('#youtube_enabled').prop("checked", newState.youtube_enabled);
+
 	$('#spotify_credentials_valid').prop("checked", newState.spotify_credentials_valid);
 
 	$('#bluetooth_scanning').prop("checked", newState.bluetooth_scanning);
@@ -106,6 +108,14 @@ $(document).ready(function() {
 		});
 	});
 
+	$('#youtube_enabled').change(function() {
+		$.post(urls['set_youtube_enabled'], {
+			value: $(this).is(":checked"),
+		}).done(function() {
+			successToast('');
+		});
+	});
+
 	$('#check_spotify_credentials').on('click tap', function() {
 		$.get(urls['check_spotify_credentials']).done(function(response) {
 			successToast(response);
@@ -157,6 +167,30 @@ $(document).ready(function() {
 		});
 	});
 
+	$('#output_devices').on('click tap', function() {
+		$.get(urls['output_devices']).done(function(response) {
+			$('#output_devices').empty();
+			$.each(response, function(i, e) {
+				let option = $('<option/>');
+				option.text(e);
+				option.on('click tap', function(e) {
+					e.stopPropagation();
+				})
+				$('#output_devices').append(option);
+			});
+		})
+	});
+	$('#set_output_device').on('click tap', function() {
+		let selected = $("#output_devices option:selected").val();
+		$.post(urls['set_output_device'], {
+			device: selected,
+		}, function(response) {
+			successToast(response);
+		}).fail(function(response) {
+			errorToast(response.responseText);
+		});
+	})
+
 	$('#wifi_ssid').focus(function () {
 		$.get(urls['available_ssids']).done(function(ssids) {
 			let available_ssids = ssids;
